@@ -129,6 +129,9 @@ def workflow_properties(class_):
                 setattr(class_, prop.key + '_editable',
                         StatusProperty(prop.target, prop.key,
                                        EDITABLE_STATUSES))
+                setattr(class_, prop.key + '_actual',
+                        StatusProperty(prop.target, prop.key,
+                                       ACTUAL_STATUSES))
 
 class ComparisonResult(object):
     def __init__(self, edited, deleted, unchanged):
@@ -338,6 +341,9 @@ class Model(object):
     def is_editable(self):
         return self.status in NEW_VERSION_STATUSES
 
+    def is_actual(self):
+        return self.status in ACTUAL_STATUSES
+
     def is_published(self):
         return self.status in PUBLISHED_STATUSES
     
