@@ -1176,7 +1176,20 @@ class ClioTestCase(unittest.TestCase):
         self.assertEquals(2, len(list(one_editable.bs)))
         self.assertEquals(clio.EDITABLE, one_editable.bs[0].status)
         self.assertEquals(clio.EDITABLE, one_editable.bs[1].status)
-    
+
+    def test_actual(self):
+        one = self._get_rel_editable()
+
+        self.assertEquals(2, len(one.bs_editable.all()))
+        self.assertEquals(2, len(one.bs_actual.all()))
+        
+        b1_deleted = one.bs[0].delete()
+        self.assert_(not b1_deleted.is_actual())
+        self.assert_(b1_deleted.is_editable())
+        
+        self.assertEquals(2, len(one.bs_editable.all()))
+        self.assertEquals(1, len(one.bs_actual.all()))
+        
     def test_compare_all_published(self):
         one = self._get_rel_published()
         
